pub struct RiMetricConfig {
pub metric_type: RiMetricType,
pub name: String,
pub help: String,
pub buckets: Vec<f64>,
pub quantiles: Vec<f64>,
pub max_age: Duration,
pub age_buckets: usize,
}Expand description
Metric configuration
Fields
metric_type: RiMetricTypename: Stringhelp: Stringbuckets: Vec<f64>quantiles: Vec<f64>max_age: Durationage_buckets: usizeTrait Implementations
Sourceimpl Clone for RiMetricConfig
impl Clone for RiMetricConfig
Sourcefn clone(&self) -> RiMetricConfig
fn clone(&self) -> RiMetricConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiMetricConfig
impl Debug for RiMetricConfig
Sourceimpl<'py> IntoPyObject<'py> for RiMetricConfig
impl<'py> IntoPyObject<'py> for RiMetricConfig
Sourcetype Target = RiMetricConfig
type Target = RiMetricConfig
The Python output type
Sourcetype Output = Bound<'py, <RiMetricConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <RiMetricConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for RiMetricConfig
impl PyClass for RiMetricConfig
Sourceimpl PyClassImpl for RiMetricConfig
impl PyClassImpl for RiMetricConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Metric configuration
const RAW_DOC: &'static CStr = /// Metric configuration
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<RiMetricConfig>
type ThreadChecker = SendablePyClass<RiMetricConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for RiMetricConfig
impl PyClassNewTextSignature for RiMetricConfig
const TEXT_SIGNATURE: &'static str = "(name, metric_type, help=\"\", buckets=None, quantiles=None)"
Sourceimpl PyMethods<RiMetricConfig> for PyClassImplCollector<RiMetricConfig>
impl PyMethods<RiMetricConfig> for PyClassImplCollector<RiMetricConfig>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for RiMetricConfig
impl PyTypeInfo for RiMetricConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for RiMetricConfig
impl ExtractPyClassWithClone for RiMetricConfig